.. highlight:: rst

Contact
=======

The lead developer and maintainer of `climlab` is

	| **Brian E. J. Rose**
	| Department of Atmospheric and Environmental Sciences
	| University at Albany
	| brose@albany.edu

Community contributions are very welcome!
Bugs can be reported through the `issue tracker <https://github.com/climlab/climlab/issues>`_ on github.


The documentation was originally created by **Moritz Kreuzer**, Potsdam Institut for Climate Impact Research (PIK).
Other contributors include

- Ryan Abernathey
- Christopher Cardinale
